@@ -16,6 +16,7 @@ __all__ = ('ResourceMeta', )
 # this magic.
 # pylint: disable=W0212
 
+from datetime import datetime
 
 from .cache import retrieve_from_cache
 from .api import TastyApi
@@ -31,6 +32,7 @@ class ResourceMeta(type):
     """Updates the TastyApi.auth for the class and all instances."""
 
     _classes = []
+    _alive = None
     _factory = None
 
     def __new__(mcs, name, bases, classdict):
@@ -57,14 +59,13 @@ class ResourceMeta(type):
         return cls.count()
 
     def __getattr__(cls, name):
-        if name not in cls.schema().list_endpoints():
+        try:
+            return_type = cls.schema().list_endpoint_type(name)
+        except KeyError:
             raise AttributeError(name)
         def _call_resource_classmethod(*args, **kwargs):
             result = cls.api().list_endpoint(cls.resource(), name, cls.schema(), *args, **kwargs)
-            try:
-                return cls.create_related_resource(result)
-            except (AttributeError, IndexError):
-                return result
+            return cls.create_field_object(result, return_type)
         return _call_resource_classmethod
 
     @staticmethod
@@ -74,6 +75,15 @@ class ResourceMeta(type):
         except TypeError:
             return details.split('/')[-3]
 
+    def _create_related_resource(cls, related_details):
+        resource_type = cls._get_resource_type(related_details)
+        resource_class = getattr(cls._factory, resource_type)
+        # Tastypie can either return a dict of fields for a resource, or simply
+        # its URI. We want to pass its fields to the new Resource.
+        if not isinstance(related_details, dict):
+            related_details = resource_class.api().details(related_details, resource_class.schema())
+        return resource_class(_details=related_details)
+
     def _set_api_auth(cls, auth):
         cls._auth = auth
         cls.api().auth = auth
@@ -86,16 +96,6 @@ class ResourceMeta(type):
 
     auth = property(lambda cls: cls._auth, _set_auth)
 
-    def create_related_resource(cls, related_details):
-        """Create a new resource from the related field."""
-        resource_type = cls._get_resource_type(related_details)
-        resource_class = getattr(cls._factory, resource_type)
-        # Tastypie can either return a dict of fields for a resource, or simply
-        # its URI. We want to pass its fields to the new Resource.
-        if not isinstance(related_details, dict):
-            related_details = resource_class.api().details(related_details, resource_class.schema())
-        return resource_class(_details=related_details)
-
     def resource(cls):
         """Return the resource name of this class."""
         if cls._class_resource is None:
@@ -120,6 +120,23 @@ class ResourceMeta(type):
             cls._class_schema = retrieve_from_cache(cls.api().schema, cls.resource())
         return cls._class_schema
 
+    def create_field_object(cls, field, field_type):
+        """Create an expected python object for the field_type."""
+        if field is None:
+            pass
+        elif field_type == tastytypes.RELATED:
+            if hasattr(field, 'split'):
+                return cls._create_related_resource(field)
+            else:
+                return [cls._create_related_resource(f) for f in field]
+        elif field_type == tastytypes.DATETIME:
+            # Try with milliseconds, otherwise without.
+            try:
+                field = datetime.strptime(field, tastytypes.DATETIME_FORMAT1)
+            except ValueError:
+                field = datetime.strptime(field, tastytypes.DATETIME_FORMAT2)
+        return field
+
     def get_resources(cls, **kwargs):
         """Return a generator of dicts from the API."""
         for field, obj in kwargs.items():
@@ -184,6 +201,16 @@ class ResourceMeta(type):
             pass
         return result
 
+    def delete_all(cls):
+        """Delete the entire collection of resources.
+
+        Besides deleting the collection of resources remotely, all local
+        Resource objects of this type will be marked as deleted (ie. using any
+        of them will result in a ResourceDeleted exception).
+        """
+        cls.api().delete_all(cls.resource(), cls.schema())
+        cls._alive = set()
+
     def count(cls, **kwargs):
         """Return the number of records for this resource.
 
@@ -246,4 +273,8 @@ class ResourceMeta(type):
         )
         # Mark each deleted resource as deleted.
         for resource in delete:
-            del cls._ALIVE[resource.uri()]
+            cls._alive.remove(resource.uri())
+
+    def help(cls, verbose=False):
+        """Return a string with the help for this resource's schema."""
+        return cls.schema().help(verbose)
