@@ -12,8 +12,6 @@
 __all__ = ('Resource', )
 
 
-from datetime import datetime
-
 from .meta import ResourceMeta
 from .exceptions import (
     ResourceDeleted,
@@ -61,7 +59,7 @@ class Resource(_BaseMetaBridge, object):
         affect all instances of a Resource, as well as the derived Resource
         class itself (TODO link to examples here)."""
 
-    _ALIVE = {}
+    _alive = set()
 
     def __init__(self, **kwargs):
         try:
@@ -69,7 +67,7 @@ class Resource(_BaseMetaBridge, object):
         except KeyError:
             _details = self._create_new_resource(self._api(), self._resource(), self._schema(), **kwargs)
         uri = _details['resource_uri']
-        self._ALIVE[uri] = True
+        self._alive.add(uri)
         self._set('_fields', _details)
         self._set('_uri', uri)
         self._set('_cached_fields', {})
@@ -93,9 +91,11 @@ class Resource(_BaseMetaBridge, object):
         try:
             return self._cached_field(name)
         except KeyError:
-            if name not in self._schema().detail_endpoints():
+            try:
+                return_type = self._schema().detail_endpoint_type(name)
+            except KeyError:
                 raise AttributeError(name)
-            return self._resource_method(name)
+            return self._resource_method(name, return_type)
 
     def __eq__(self, obj):
         try:
@@ -107,18 +107,15 @@ class Resource(_BaseMetaBridge, object):
         return hash(self.uri())
 
     def __bool__(self):
-        return self.uri() in self._ALIVE
+        return self.uri() in self._alive
 
     # TODO Eventually remove: This is only for python2.x compatability
     __nonzero__ = __bool__
 
-    def _resource_method(self, method_name):
+    def _resource_method(self, method_name, return_type):
         def _call_resource_method(*args, **kwargs):
             result = self._api().detail_endpoint(self, method_name, self._schema(), *args, **kwargs)
-            try:
-                return self._new_related_resource(result)
-            except (AttributeError, IndexError):
-                return result
+            return self._create_field_object(result, return_type)
         return _call_resource_method
 
     def _create_new_resource(self, api, resource, schema, **kwargs):
@@ -126,10 +123,7 @@ class Resource(_BaseMetaBridge, object):
         details = api.add(resource, schema, **fields)
         if not details:
             try:
-                # No more than two results are needed, so save the server's resources.
-                # TODO This is in more than one place:
-                if 'limit' not in kwargs:
-                    kwargs['limit'] = 2
+                kwargs['limit'] = 2
                 fields = schema.remove_fields_not_in_filters(kwargs)
                 results = type(self).get_resources(**fields)
                 resources = next(iter(results))['objects']
@@ -157,28 +151,11 @@ class Resource(_BaseMetaBridge, object):
                     fields[name] = value.uri()
         return fields
 
-    def _create_field_object(self, name, field, field_type):
-        if field is None:
-            pass
-        elif field_type == tastytypes.RELATED:
-            related_type = self._schema().field(name)['related_type']
-            if related_type == tastytypes.TO_MANY:
-                return [self._new_related_resource(f) for f in field]
-            else:
-                return self._new_related_resource(field)
-        elif field_type == tastytypes.DATETIME:
-            # Try with milliseconds, otherwise without.
-            try:
-                field = datetime.strptime(field, tastytypes.DATETIME_FORMAT1)
-            except ValueError:
-                field = datetime.strptime(field, tastytypes.DATETIME_FORMAT2)
-        return field
-
     def _cached_field(self, name):
         if name not in self._cached_fields or not self._caching:
             field = self.fields()[name]
             field_type = self._schema().field(name)['type']
-            self._cached_fields[name] = self._create_field_object(name, field, field_type)
+            self._cached_fields[name] = self._create_field_object(field, field_type)
         return self._cached_fields[name]
 
     def _set(self, name, value):
@@ -189,7 +166,7 @@ class Resource(_BaseMetaBridge, object):
     _api = classmethod(lambda cls: cls.api())
     _resource = classmethod(lambda cls: cls.resource())
     _schema = classmethod(lambda cls: cls.schema())
-    _new_related_resource = classmethod(lambda cls, fields: cls.create_related_resource(fields))
+    _create_field_object = classmethod(lambda cls, field, field_type: cls.create_field_object(field, field_type))
 
     def uri(self):
         """Return the resource_uri for this object.
@@ -218,7 +195,7 @@ class Resource(_BaseMetaBridge, object):
         """
         self.check_alive()
         self._api().delete(self.uri(), self._schema())
-        del self._ALIVE[self.uri()]
+        self._alive.remove(self.uri())
 
     def set_caching(self, caching):
         """Set whether this object should cache its fields.
@@ -273,12 +250,9 @@ class Resource(_BaseMetaBridge, object):
         fields locally (default). It is still possible to call this method when
         caching is set to False, but there won't be a noticable effect.
         """
+        self.check_alive()
         self._update_remote_fields(**self._cached_fields)
 
-    def help(self, verbose=False):
-        """Return a string with the help for this resource's schema."""
-        return self._schema().help(verbose)
-
     def _get_max_results(self):
         return self._api().max_results
 
