@@ -20,6 +20,7 @@ from .exceptions import (
     NoFiltersInSchema,
     FieldNotInSchema,
     FilterNotAllowedForField,
+    InvalidFieldName,
 )
 
 
@@ -66,6 +67,7 @@ class TastySchema(object):
     def __init__(self, data, resource):
         self._resource = resource
         self._schema = data
+        self._check_schema()
 
     def __str__(self):
         return str(self._schema) if self._schema else repr(self)
@@ -108,6 +110,12 @@ class TastySchema(object):
         except ValueError:
             pass
 
+    def _check_schema(self):
+        if 'limit' in self._fields():
+            raise InvalidFieldName("'limit' cannot be used as a field name.")
+        if 'order_by' in self._fields():
+            raise InvalidFieldName("'order_by' cannot be used as a field name.")
+
     def filterable_key(self):
         """Return a field that both: has unique values; and can be filtered on (defaults to 'id').
 
@@ -135,27 +143,21 @@ class TastySchema(object):
         if schema_field['readonly']:
             raise ReadOnlyField(self._resource, field)
 
-    def detail_endpoints(self):
+    def detail_endpoint_type(self, endpoint):
         """Return a list of all endpoints for this resource instance.
 
         :returns: The endpoints for this resource instance.
         :rtype: list
         """
-        try:
-            return self._schema['detail_endpoints'].keys()
-        except KeyError:
-            return []
+        return self._schema['detail_endpoints'][endpoint]['type']
 
-    def list_endpoints(self):
+    def list_endpoint_type(self, endpoint):
         """Return a list of all endpoints for this resource type.
 
         :returns: The endpoints for this resource type.
         :rtype: list
         """
-        try:
-            return self._schema['list_endpoints'].keys()
-        except KeyError:
-            return []
+        return self._schema['list_endpoints'][endpoint]['type']
 
     def field(self, name):
         """Return the description of the given field.
@@ -260,6 +262,30 @@ class TastySchema(object):
         method_text = method_text[:-2] if method_text else ''
         return method_text
 
+    def _help_endpoints(self, endpoint_type, verbose):
+        help_text = ''
+        for endpoint, desc in self._schema[endpoint_type].items():
+            if verbose:
+                help_text += (
+                    '\n{0}\n'
+                    '{1}\n'
+                    'Description : {2}\n'
+                    'Return Type : {3}\n'
+                    ''.format(
+                        endpoint,
+                        '^' * len(endpoint),
+                        desc['help_text'],
+                        desc['type'],
+                    )
+                )
+            else:
+                help_text += '{0} [{1}] -- {2}\n'.format(
+                    endpoint,
+                    desc['type'],
+                    desc['help_text'],
+                )
+        return help_text
+
     def help(self, verbose):
         """Returns a string containing the help text for this resource.
 
@@ -319,4 +345,14 @@ class TastySchema(object):
                     desc['type'] if desc['type'] != 'related' else related_type(desc),
                     self._help_description(desc['help_text']),
                 )
+        help_text += '\nCustom List Endpoints\n---------------------\n'
+        try:
+            help_text += self._help_endpoints('list_endpoints', verbose)
+        except KeyError:
+            help_text += 'No list endpoints.\n'
+        help_text += '\nCustom Detail Endpoints\n-----------------------\n'
+        try:
+            help_text += self._help_endpoints('detail_endpoints', verbose)
+        except KeyError:
+            help_text += 'No detail_endpoints.\n'
         return unicode(help_text)
